@@ -1,5 +1,3 @@
-/* $Id: glibtop_machine.h,v 1.12 2003/10/20 15:19:49 hadess Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -35,9 +33,7 @@
 
 #include <fcntl.h>
 
-#ifdef __FreeBSD__
 #include <osreldate.h>
-#endif
 
 G_BEGIN_DECLS
 
@@ -47,7 +43,7 @@ struct _glibtop_machine
 {
 	uid_t uid, euid;
 	gid_t gid, egid;
-	
+
 	/* The kernel descriptor, used by kvm_* calls.  We keep and re-use
 	 * it rather than re-getting it for almost all function
 	 * invocations. */
